@@ -46,9 +46,8 @@ class H2OAutoML(H2OAutoMLParams, H2OSupervisedAlgorithmWithFoldColumn, H2OAutoML
                  splitRatio=1.0,
                  monotoneConstraints={},
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  projectName=None,
-                 nfolds=5,
+                 nfolds=-1,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
